@@ -45,12 +45,8 @@ importWQP <- function(obs_url, tz = "UTC",
     tz <- "UTC"
   }
 
-  if (!file.exists(obs_url)) {
-    
-    doc <- getWebServiceData(
-      obs_url,
-      httr::accept("text/csv")
-    )
+  if (inherits(obs_url, "httr2_request")) {
+    doc <- getWebServiceData(obs_url)
     if (is.null(doc)) {
       return(invisible(NULL))
     }
@@ -71,6 +67,10 @@ importWQP <- function(obs_url, tz = "UTC",
   
   attr(retval, 'spec') <- NULL
   
+  if(any(grepl("ERROR: INCOMPLETE DATA", retval[1,]))){
+    stop(retval[[1]])
+  }
+  
   # this is only needed for legacy
   names(retval)[grep("/", names(retval))] <- gsub("/", ".", names(retval)[grep("/", names(retval))])
   
@@ -78,8 +78,9 @@ importWQP <- function(obs_url, tz = "UTC",
   if(convertType){
     retval <- parse_WQP(retval, tz)
   } 
-  attr(retval, "headerInfo") <- headerInfo
-  
+  if (inherits(obs_url, "httr2_request")) {
+    attr(retval, "headerInfo") <- headerInfo
+  }
   return(retval)
   
 }
@@ -152,10 +153,17 @@ parse_WQP <- function(retval, tz = "UTC"){
     dateCols_to_convert <- NA
     for(date_col in dateCols){
       
+      # Legacy:
       time_col <- gsub("Date", "Time", date_col)
-      tz_col <- gsub("Date", "TimeZone", date_col)      
+      tz_col <- paste0(time_col, ".TimeZoneCode")  
+      time_col <- paste0(time_col, ".Time") 
+      
+      # WQX3:
+      time_col_wqx3 <- gsub("Date", "Time", date_col)
+      tz_col_wqx3 <- gsub("Date", "TimeZone", date_col) 
       
       if(all(c(date_col, time_col, tz_col) %in% names(retval))){
+        # Legacy
         if(!all(is.na(retval[[date_col]]))){
           retval <- create_dateTime(retval, 
                                     date_col = date_col,
@@ -163,6 +171,16 @@ parse_WQP <- function(retval, tz = "UTC"){
                                     tz_col = tz_col,
                                     tz = tz)
         }
+        
+      } else if(all(c(date_col, time_col_wqx3, tz_col_wqx3) %in% names(retval))){
+        # WQX3
+        if(!all(is.na(retval[[date_col]]))){
+          retval <- create_dateTime(retval, 
+                                    date_col = date_col,
+                                    time_col = time_col_wqx3,
+                                    tz_col = tz_col_wqx3,
+                                    tz = tz)
+        }        
       } else {
         # This is the legacy pattern:
         time_col <- gsub("Date", "Time.Time", date_col)
