@@ -43,8 +43,7 @@
 #'
 #' @param \dots see \url{https://www.waterqualitydata.us/webservices_documentation} for a complete list of options.
 #' A list of arguments can also be supplied. For more information see the above 
-#' description for this help file. If no "service" argument is supplied, it
-#' will default to "ResultWQX3". One way to figure out how to construct a WQP query is to go to the "Advanced" 
+#' description for this help file. One way to figure out how to construct a WQP query is to go to the "Advanced" 
 #' form in the Water Quality Portal. Use the form to discover what parameters are available. Once the query is 
 #' set in the form, scroll down to the "Query URL". You will see the parameters
 #' after "https://www.waterqualitydata.us/#". For example, if you chose "Nutrient"
@@ -86,12 +85,21 @@
 #' @examplesIf is_dataRetrieval_user()
 #' \donttest{
 #' 
+#' # Legacy:
 #' nameToUse <- "pH"
 #' pHData <- readWQPdata(siteid = "USGS-04024315", 
 #'                       characteristicName = nameToUse)
 #' ncol(pHData)
 #' attr(pHData, "siteInfo")
 #' attr(pHData, "queryTime")
+#' attr(pHData, "url")
+#' 
+#' # WQX3:
+#' pHData_wqx3 <- readWQPdata(siteid = "USGS-04024315", 
+#'                       characteristicName = nameToUse,
+#'                       service = "ResultWQX3",
+#'                       dataProfile = "basicPhysChem")
+#' attr(pHData_wqx3, "url")
 #'
 #' # More examples:
 #' # querying by county
@@ -101,11 +109,30 @@
 #'   characteristicName = "Nitrogen"
 #' )
 #' 
+#' attr(DeWitt, "url")
+#' 
+#' DeWitt_wqx3 <- readWQPdata(
+#'   statecode = "Illinois",
+#'   countycode = "DeWitt",
+#'   characteristicName = "Nitrogen",
+#'   service = "ResultWQX3",
+#'   dataProfile = "basicPhysChem",  
+#'   ignore_attributes = TRUE)
+#' 
+#' attr(DeWitt_wqx3, "url")
+#' 
 #' # Data profile: "Sampling Activity"
 #' activity <- readWQPdata(
 #'   siteid = "USGS-04024315",
 #'   service = "Activity"
 #' )
+#' attr(activity, "url")
+#' 
+#' activity_wqx3 <- readWQPdata(
+#'   siteid = "USGS-04024315",
+#'   service = "ActivityWQX3"
+#' )
+#' attr(activity_wqx3, "url")
 #' 
 #' Dane_activity <- readWQPdata(
 #'   statecode = "Wisconsin",
@@ -114,14 +141,20 @@
 #'   startDateHi = "2023-12-31",
 #'   service = "Activity"
 #' )
+#' attr(Dane_activity, "url")
+#' 
+#' Dane_activity_wqx3 <- readWQPdata(
+#'   statecode = "Wisconsin",
+#'   countycode = "Dane",
+#'   startDateLo = "2023-01-01",
+#'   startDateHi = "2023-12-31",
+#'   service = "ActivityWQX3"
+#' )
+#' attr(Dane_activity_wqx3, "url")
 #' 
 #' ########################################################
 #' # Additional examples:
 #'
-#' pHData_legacy <- readWQPdata(siteid = "USGS-04024315", 
-#'                       characteristicName = nameToUse,
-#'                       service = "Result",
-#'                       dataProfile = "narrowResult")
 #'  
 #' # Data profiles: "Organization Data" 
 #' org_data <- readWQPdata(
@@ -157,6 +190,7 @@
 #'   dataProfile = "biological",
 #'   service = "Result"
 #' )
+#' 
 #'
 #' # Data profiles: "Sample Results (narrow)" 
 #' samp_narrow <- readWQPdata(
@@ -165,6 +199,13 @@
 #'   dataProfile = "narrowResult"
 #' )
 #'
+#' samp_narrow_wqx3 <- readWQPdata(
+#'   siteid = "USGS-04024315",
+#'   service = "ResultWQX3",
+#'   dataProfile = "narrow"
+#' )
+#'
+#'
 #' # Data profiles: "Sampling Activity"  
 #' samp_activity <- readWQPdata(
 #'   siteid = "USGS-04024315",
@@ -193,6 +234,17 @@
 #'   ignore_attributes = TRUE,
 #'   convertType = FALSE
 #' )
+#' 
+#' rawPHsites_legacy <- readWQPdata(siteid = c("USGS-05406450", "USGS-05427949", "WIDNR_WQX-133040"),
+#'                         characteristicName = "pH",
+#'                         service = "Result",
+#'                         dataProfile = "narrowResult" )
+#' 
+#' rawPHsites <- readWQPdata(siteid = c("USGS-05406450", "USGS-05427949", "WIDNR_WQX-133040"),
+#'                         characteristicName = "pH",
+#'                         service = "ResultWQX3",
+#'                         dataProfile = "narrow" )
+#' 
 #' }
 readWQPdata <- function(...,
                         service = "Result",
@@ -214,18 +266,30 @@ readWQPdata <- function(...,
   legacy <- is_legacy(service)
   
   valuesList <- readWQPdots(..., legacy = legacy)
+  values <- valuesList[["values"]]
+
+  baseURL <- httr2::request(pkg.env[[service]])
   
-  values <- sapply(valuesList$values, function(x) utils::URLencode(x, reserved = TRUE))
-
-  baseURL <- drURL(service, arg.list = values)
-
-  baseURL <- appendDrURL(baseURL, mimeType = "csv")
-
   if(!legacy){
     if(service == "ResultWQX3" & !"dataProfile" %in% names(values)){
-      baseURL <- appendDrURL(baseURL, dataProfile = "fullPhysChem")
+      baseURL <- httr2::req_url_query(baseURL, 
+                                      dataProfile = "fullPhysChem")
     }
-  } 
+    baseURL <- httr2::req_url_query(baseURL, !!!values, 
+                                    .multi = "explode")
+  } else {
+    if("siteid" %in% names(values)){
+      if(length(values[["siteid"]]) > 1){
+        sites <- values[["siteid"]]
+        baseURL <- httr2::req_url_query(baseURL, 
+                                        siteid = sites,
+                                        .multi = function(x) paste0(x, collapse = ";"))
+        values <- values[names(values) != "siteid"]
+      }
+    }
+    baseURL <- httr2::req_url_query(baseURL, !!!values, 
+                                    .multi = "explode")
+  }
 
   if (querySummary) {
     retquery <- getQuerySummary(baseURL)
@@ -242,13 +306,15 @@ readWQPdata <- function(...,
     
     attr(retval, "legacy") <- legacy
     
-    if (!all(is.na(retval)) && !ignore_attributes) {
-      params <- list(...)
+    if (!all(is.na(retval)) && 
+        !ignore_attributes && 
+        !service %in% c("Station", "StationWQX")) {
+      params <- convertLists(...)
       params <- params[!names(params) %in% c("dataProfile", "service")]
       retval <- create_WQP_attributes(retval, params)
     } 
 
-    attr(retval, "url") <- baseURL
+    attr(retval, "url") <- baseURL$url
     
     if(legacy){
       wqp_message()
@@ -264,6 +330,29 @@ readWQPdata <- function(...,
 
 create_WQP_attributes <- function(retval, ...){
 
+  col_legacy <- c("CharacteristicName", #legacy
+                  "ResultMeasure.MeasureUnitCode", 
+                  "ResultSampleFractionText")
+  col_wqx3 <- c("Result_Characteristic", #wqx3
+                "Result_MeasureUnit", 
+                "Result_SampleFraction")
+  if (all(col_legacy %in% names(retval))) {
+    retvalVariableInfo <- retval[, col_legacy]
+    retvalVariableInfo <- unique(retvalVariableInfo)
+    names(retvalVariableInfo) <- c("characteristicName",
+                                   "param_units",
+                                   "valueType")
+
+    attr(retval, "variableInfo") <- retvalVariableInfo
+  } else if(all(col_wqx3 %in% names(retval))){
+    retvalVariableInfo <- retval[, col_wqx3]
+    retvalVariableInfo <- unique(retvalVariableInfo)
+    names(retvalVariableInfo) <- c("characteristicName",
+                                   "param_units",
+                                   "valueType")
+    
+    attr(retval, "variableInfo") <- retvalVariableInfo
+  }
   
   siteInfo <- suppressWarnings(whatWQPsites(..., legacy = attr(retval, "legacy")))
   attr(retval, "siteInfo") <- siteInfo
@@ -276,8 +365,6 @@ create_WQP_attributes <- function(retval, ...){
     attr(retval, "queryTime") <- Sys.time()
   }
   
-  
-  
   return(retval)
 }
 
@@ -296,7 +383,8 @@ create_WQP_attributes <- function(retval, ...){
 #' 
 #' @examplesIf is_dataRetrieval_user()
 #' \donttest{
-#' rawPcode <- readWQPqw("USGS-01594440", "01075", ignore_attributes = TRUE)
+#' rawPcode <- readWQPqw("USGS-01594440", "01075", 
+#'                       ignore_attributes = TRUE, legacy = FALSE)
 #' headerInfo <- attr(rawPcode, "headerInfo")
 #' wqp_request_id <- headerInfo$`wqp-request-id`
 #' count_info <- wqp_check_status(wqp_request_id)
